@@ -37,7 +37,7 @@ static void do_file_summary_output(slist *sptr);
 static void do_string_summary_output(slist *sptr);
 static void do_user_summary_output(slist *sptr);
 static void do_int_summary_output(ilist *sptr);
-static void do_syscall_summary_output(ilist *sptr);
+static void do_syscall_summary_output(slist *sptr);
 static void do_type_summary_output(ilist *sptr);
 
 /* Local Data */
@@ -490,7 +490,10 @@ void print_per_event_item(llist *l)
 
 	// The beginning is common to all reports
 	tv = localtime(&l->e.sec);
-	strftime(date, sizeof(date), "%x %T", tv);
+	if (tv)
+		strftime(date, sizeof(date), "%x %T", tv);
+	else
+		strcpy(date, "?");
 	if (report_type != RPT_AVC) {
 		line_item++;
 		printf("%u. %s ", line_item, date);
@@ -572,8 +575,17 @@ void print_per_event_item(llist *l)
 			break;
 		case RPT_FILE:	// report_detail == D_DETAILED
 			// file, syscall, success, exe, who, event
-			slist_first(l->s.filename);
-			safe_print_string(l->s.filename->cur->str,0);
+			{
+			slist *s = l->s.filename;
+			slist_first(s);
+			if (s->cnt > 1) {
+				char *key = s->cur->key;
+				while (key && strcmp(key, "PARENT") == 0) {
+					slist_next(s);
+					key = s->cur->key;
+				}
+			}
+			safe_print_string(s->cur->str,0);
 			printf(" %s %s ",
 				aulookup_syscall(l,buf,sizeof(buf)),
 				aulookup_success(l->s.success));
@@ -582,6 +594,7 @@ void print_per_event_item(llist *l)
 			safe_print_string(aulookup_uid(l->s.loginuid, name,
 					sizeof(name)), 0);
 			printf(" %lu\n", l->e.serial);
+			}
 			break;
 		case RPT_HOST:	// report_detail == D_DETAILED
 			// host, syscall, who, event
@@ -785,7 +798,7 @@ void print_wrap_up(void)
 			do_int_summary_output(&sd.pids);
 			break;
 		case RPT_SYSCALL:
-			ilist_sort_by_hits(&sd.sys_list);
+			slist_sort_by_hits(&sd.sys_list);
 			do_syscall_summary_output(&sd.sys_list);
 			break;
 		case RPT_TERM:
@@ -848,10 +861,16 @@ static void do_summary_output(void)
 		char tmp[48];
 
 		btm = localtime(&very_first_event.sec);
-		strftime(tmp, sizeof(tmp), "%x %T", btm);
+		if (btm)
+			strftime(tmp, sizeof(tmp), "%x %T", btm);
+		else
+			strcpy(tmp, "?");
 		printf("%s.%03d - ", tmp, very_first_event.milli);
 		btm = localtime(&very_last_event.sec);
-		strftime(tmp, sizeof(tmp), "%x %T", btm);
+		if (btm)
+			strftime(tmp, sizeof(tmp), "%x %T", btm);
+		else
+			strcpy(tmp, "?");
 		printf("%s.%03d\n", tmp, very_last_event.milli);
 	}
 	printf("Selected time for report: ");
@@ -863,13 +882,19 @@ static void do_summary_output(void)
 			btm = localtime(&start_time);
 		else
 			btm = localtime(&very_first_event.sec);
-		strftime(tmp, sizeof(tmp), "%x %T", btm);
+		if (btm)
+			strftime(tmp, sizeof(tmp), "%x %T", btm);
+		else
+			strcpy(tmp, "?");
 		printf("%s - ", tmp);
 		if (end_time) 
 			btm = localtime(&end_time);
 		else 
 			btm = localtime(&very_last_event.sec);
-		strftime(tmp, sizeof(tmp), "%x %T", btm);
+		if (btm)
+			strftime(tmp, sizeof(tmp), "%x %T", btm);
+		else
+			strcpy(tmp, "?");
 		if (end_time) 
 			printf("%s\n", tmp);
 		else 
@@ -978,26 +1003,20 @@ static void do_int_summary_output(ilist *sptr)
 	}
 }
 
-static void do_syscall_summary_output(ilist *sptr)
+static void do_syscall_summary_output(slist *sptr)
 {
-	const int_node *in;
+	const snode *sn;
 
 	if (sptr->cnt == 0) {
 		printf("<no events of interest were found>\n\n");
 		return;
 	}
-	ilist_first(sptr);
-	in=ilist_get_cur(sptr);
-	while (in) {
-		const char *sys = NULL;
-		int machine = audit_elf_to_machine(in->aux1);
-		if (machine >= 0) 
-			sys = audit_syscall_to_name(in->num, machine);
-		if (sys) 
-			printf("%u  %s\n", in->hits, sys);
-		else
-			printf("%u  %d\n", in->hits, in->num);
-		in=ilist_next(sptr);
+	slist_first(sptr);
+	sn=slist_get_cur(sptr);
+	while (sn) {
+		printf("%u  ", sn->hits);
+		safe_print_string(sn->str, 1);
+		sn=slist_next(sptr);
 	}
 }
 
